// Copyright 2022 schukai GmbH
// SPDX-License-Identifier: AGPL-3.0-or-later

package negotiation

import (
	"net/http"
	"testing"
)

func TestParser(t *testing.T) {
	p := newHeaderParser(nil, false)
	if p.wildCard != "*" {
		t.Errorf("wildCard should be '*', but is %s", p.wildCard)
	}
}

func TestParserSlash(t *testing.T) {
	p := newHeaderParser(nil, true)
	if p.wildCard != "*/*" {
		t.Errorf("wildCard should be '*/*', but is %s", p.wildCard)
	}
}

func TestParserSlash2(t *testing.T) {
	p := newHeaderParser(nil, false)
	if p.wildCard != "*" {
		t.Errorf("wildCard should be '*', but is %s", p.wildCard)
	}
}

func FuzzTestParser(f *testing.F) {

	f.Fuzz(func(t *testing.T, acceptString, a, b string) {

		req, err := http.NewRequest("Get", "/", nil)
		if err != nil {
			t.Fatal(err)
		}

		req.Header.Set("Accept", acceptString)

		p := newHeaderParser(req.Header, false)
		spec := p.parse("Accept")
		if spec == nil {
			t.Errorf("spec should not be nil")
		}

	})
}
